Tutorial 3: Fitting with Bounds
================================

.. deprecated::
   This tutorial has been superseded by the structured tutorial guide.

See :doc:`/tutorials/routine/data_handling/bounds` for the updated version.
